GoogleSearch_services_types.urn_GoogleSearch.ResultElementArray_Def

|  | ## Cheshire3 Object Model: Class ResultElementArray_Def

Module GoogleSearch_services_types :: Class urn_GoogleSearch :: Class ResultElementArray_Def

## Class ResultElementArray_Def
source code

Object Tree:

         TC.TypeCode --+
                       |
    ZSI.TCcompound.Array --+
                           |
                          ResultElementArray_Def

Instance Methods

__init__(self, name=None, ns=None, **kw)
Inherited from `ZSI.TCcompound.Array`: `parse`, `parse_offset`, `parse_position`, `serialize` Inherited from `ZSI.TC.TypeCode`: `SimpleHREF`, `checkname`, `checktype`, `get_parse_and_errorlist`, `name_match`, `nilled`, `simple_value`

Class Variables

Inherited from `ZSI.TC.TypeCode`: `typechecks`

Method Details

### __init__(self, name=None, ns=None, **kw) (Constructor) | source code
Overrides: ZSI.TCcompound.Array.__init__